@@ -40,13 +40,13 @@ Messaging
    <mk>voice chat between two pc's via encrypted mumble</mk>
    <nb>voice chat between two pc's via encrypted mumble</nb>
    <nl>voice chat tussen twee PCs via beveiligde mumble</nl>
-   <pl>voice chat between two pc's via encrypted mumble</pl>
+   <pl>czat głosowy pomiędzy dwoma komputerami szyfrowany przez mumble</pl>
    <pt_BR>Chat de voz entre dois computadores via mumble encriptado</pt_BR>
    <pt>Chat de voz entre dois computadores via mumble encriptado</pt>
    <ro>voice chat between two pc's via encrypted mumble</ro>
    <ru>Голосовой чат между двумя PC через шифрованный канал</ru>
    <sk>voice chat between two pc's via encrypted mumble</sk>
-   <sl>voice chat between two pc's via encrypted mumble</sl>
+   <sl>Glasovni povogovr med dvema računalnikoma preko šifriranega Mumble</sl>
    <sq>voice chat between two pc's via encrypted mumble</sq>
    <sr>voice chat between two pc's via encrypted mumble</sr>
    <sv>röstchatt mellan två pc's via encrypted mumble</sv>
