@@ -19,7 +19,7 @@ Russian_Firefox
    <de>Russische Lokalisierung von Firefox</de>
    <el>Ρωσικός εντοπισμός του Firefox</el>
    <en>Russian localisation of Firefox</en>
-   <es>Russian localisation of Firefox</es>
+   <es>Localización Rusa de Firefox</es>
    <et>Russian localisation of Firefox</et>
    <eu>Russian localisation of Firefox</eu>
    <fa>Russian localisation of Firefox</fa>
@@ -40,11 +40,11 @@ Russian_Firefox
    <mk>Russian localisation of Firefox</mk>
    <nb>Russian localisation of Firefox</nb>
    <nl>Russische lokalisatie van Firefox</nl>
-   <pl>Russian localisation of Firefox</pl>
+   <pl>Rosyjska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Russo Localização para Firefox</pt_BR>
    <pt>Russo Localização para Firefox</pt>
    <ro>Russian localisation of Firefox</ro>
-   <ru>Русский перевод для Firefox</ru>
+   <ru>Русская локализация Firefox</ru>
    <sk>Russian localisation of Firefox</sk>
    <sl>Russian localisation of Firefox</sl>
    <sq>Russian localisation of Firefox</sq>
