@@ -38,7 +38,6 @@ Waterfox
    <ko>alternative mozilla-based browser</ko>
    <lt>alternative mozilla-based browser</lt>
    <mk>alternative mozilla-based browser</mk>
-   <mr>alternative mozilla-based browser</mr>
    <nb>alternative mozilla-based browser</nb>
    <nl>alternatieve op mozilla gebaseerde browser</nl>
    <pl>alternatywna przeglądarka oparta na Mozilli</pl>
@@ -47,7 +46,7 @@ Waterfox
    <ro>alternative mozilla-based browser</ro>
    <ru>Браузер основанный на Firefox (сохранена поддержка дополнений на XUL/XPCOM)</ru>
    <sk>alternative mozilla-based browser</sk>
-   <sl>Alternativni brskalnik, ki temelji na Mozilli</sl>
+   <sl>alternative mozilla-based browser</sl>
    <sq>alternative mozilla-based browser</sq>
    <sr>alternative mozilla-based browser</sr>
    <sv>alternativ mozilla-baserad webbläsare</sv>
@@ -67,18 +66,17 @@ Waterfox
 </preinstall>
 
 <install_package_names>
-waterfox-classic-kpe
+waterfox
+waterfox-locale-$(locale |grep LANG|cut -d= -f2 |cut -d_ -f1)
 </install_package_names>
 
 
 <postinstall>
-if [ "$(locale |grep LANG|cut -d= -f2 |cut -d_ -f1)" != "en" ]; then 
-apt-get install waterfox-classic-i18n-$(locale |grep LANG|cut -d= -f2 |cut -d_ -f1) 
-fi
+
 </postinstall>
 
 
 <uninstall_package_names>
-waterfox-classic-kpe
+waterfox
 </uninstall_package_names>
 </app>
